@@ -83,14 +83,14 @@ def run():
 
 # Creating command
 @run.command(name='run')
-@click.argument("testrun_id")
+@click.option('--testrun_id','-id', required=True)
 @click.option('--wait_time','-w', default=30, required=False)
 @click.option('--git_pass','-p', required=False)
 def run(testrun_id, git_pass, wait_time):
     """If this command is run with testrun id as an argument, aitest CLI will create new test for you with same configuration of provided testrun id.Enter git password with -p only if you used git url of the automation code for creating the test otherwise no need to enter git password.
-       Enter the waiting time in minutes with -w as an argument, To wait for looking the testrun status.\n
+       Enter the waiting time in minutes with -w as an argument, To wait for looking the testrun status in given time.\n
        To re-run the test, you can run below command:\n
-       aitest run [testrun id] -p [git password] -w [wait_time]
+       aitest run -id [testrun id] -p [git password] -w [wait_time]
     """    
     try: 
         if os.environ["USER_ID"] and os.environ["CLIENT_ID"] and os.environ["CLIENT_SECRET_ID"]:
@@ -183,11 +183,11 @@ def status():
 
 # Creating command
 @status.command(name='status')
-@click.argument("testrun_id")
+@click.option('--testrun_id','-id', required=True)
 def status(testrun_id):
     """ If this command is run with testrun id as an argument, aitest CLI will display the test details .\n  
         To see the status of test , you can run below command:\n
-        aitest status [testrun_id]
+        aitest status -id [testrun_id]
     """
     try: 
         if os.environ["USER_ID"] and os.environ["CLIENT_ID"] and os.environ["CLIENT_SECRET_ID"]:
